from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Directory, String, Int, File, Boolean, Float

Gmapl_Sse42_V0_1_0 = CommandToolBuilder(tool="gmapl.sse42", base_command=["gmapl.sse42"], inputs=[ToolInput(tag="in_dir", input_type=Directory(optional=True), prefix="--dir", doc=InputDocumentation(doc="Genome directory.  Default (as specified by --with-gmapdb to the configure program) is\n/usr/local/share")), ToolInput(tag="in_db", input_type=String(optional=True), prefix="--db", doc=InputDocumentation(doc="Genome database.  If argument is '?' (with\nthe quotes), this command lists available databases.")), ToolInput(tag="in_km_er", input_type=Int(optional=True), prefix="--kmer", doc=InputDocumentation(doc="kmer size to use in genome database (allowed values: 16 or less).\nIf not specified, the program will find the highest available\nkmer size in the genome database")), ToolInput(tag="in_sampling", input_type=Int(optional=True), prefix="--sampling", doc=InputDocumentation(doc="Sampling to use in genome database.  If not specified, the program\nwill find the smallest available sampling value in the genome database\nwithin selected k-mer size")), ToolInput(tag="in_gs_eg", input_type=File(optional=True), prefix="--gseg", doc=InputDocumentation(doc="User-supplied genomic segment")), ToolInput(tag="in_self_align", input_type=Boolean(optional=True), prefix="--selfalign", doc=InputDocumentation(doc="Align one sequence against itself in FASTA format via stdin\n(Useful for getting protein translation of a nucleotide sequence)")), ToolInput(tag="in_pair_align", input_type=Boolean(optional=True), prefix="--pairalign", doc=InputDocumentation(doc="Align two sequences in FASTA format via stdin, first one being\ngenomic and second one being cDNA")), ToolInput(tag="in_cmdline", input_type=String(optional=True), prefix="--cmdline", doc=InputDocumentation(doc=",STRING        Align these two sequences provided on the command line,\nfirst one being genomic and second one being cDNA")), ToolInput(tag="in_part", input_type=Int(optional=True), prefix="--part", doc=InputDocumentation(doc="/INT             Process only the i-th out of every n sequences\ne.g., 0/100 or 99/100 (useful for distributing jobs\nto a computer farm).")), ToolInput(tag="in_input_buffer_size", input_type=Int(optional=True), prefix="--input-buffer-size", doc=InputDocumentation(doc="Size of input buffer (program reads this many sequences\nat a time for efficiency) (default 1000)")), ToolInput(tag="in_batch", input_type=Int(optional=True), prefix="--batch", doc=InputDocumentation(doc="Batch mode (default = 2)")), ToolInput(tag="in_use_shared_memory", input_type=Int(optional=True), prefix="--use-shared-memory", doc=InputDocumentation(doc="If 1, then allocated memory is shared among all processes on this node\nIf 0 (default), then each process has private allocated memory")), ToolInput(tag="in_no_splicing", input_type=Boolean(optional=True), prefix="--nosplicing", doc=InputDocumentation(doc="Turns off splicing (useful for aligning genomic sequences\nonto a genome)")), ToolInput(tag="in_max_deletion_length", input_type=Int(optional=True), prefix="--max-deletionlength", doc=InputDocumentation(doc="Max length for a deletion (default 100).  Above this size,\na genomic gap will be considered an intron rather than a deletion.\nIf the genomic gap is less than --max-deletionlength and greater\nthan --min-intronlength, a known splice site or splice site probabilities\nof 0.80 on both sides will be reported as an intron.")), ToolInput(tag="in_min_intron_length", input_type=Int(optional=True), prefix="--min-intronlength", doc=InputDocumentation(doc="Min length for one internal intron (default 9).  Below this size,\na genomic gap will be considered a deletion rather than an intron.\nIf the genomic gap is less than --max-deletionlength and greater\nthan --min-intronlength, a known splice site or splice site probabilities\nof 0.80 on both sides will be reported as an intron.")), ToolInput(tag="in_max_intron_length_middle", input_type=Int(optional=True), prefix="--max-intronlength-middle", doc=InputDocumentation(doc="Max length for one internal intron (default 500000).  Note: for backward\ncompatibility, the -K or --intronlength flag will set both\n--max-intronlength-middle and --max-intronlength-ends.\nAlso see --split-large-introns below.")), ToolInput(tag="in_max_intron_length_ends", input_type=Int(optional=True), prefix="--max-intronlength-ends", doc=InputDocumentation(doc="Max length for first or last intron (default 10000).  Note: for backward\ncompatibility, the -K or --intronlength flag will set both\n--max-intronlength-middle and --max-intronlength-ends.")), ToolInput(tag="in_split_large_introns", input_type=Boolean(optional=True), prefix="--split-large-introns", doc=InputDocumentation(doc="Sometimes GMAP will exceed the value for --max-intronlength-middle,\nif it finds a good single alignment.  However, you can force GMAP\nto split such alignments by using this flag")), ToolInput(tag="in_trim_end_exons", input_type=Int(optional=True), prefix="--trim-end-exons", doc=InputDocumentation(doc="Trim end exons with fewer than given number of matches\n(in nt, default 12)")), ToolInput(tag="in_local_splice_dist", input_type=Int(optional=True), prefix="--localsplicedist", doc=InputDocumentation(doc="Max length for known splice sites at ends of sequence\n(default 2000000)")), ToolInput(tag="in_total_length", input_type=Int(optional=True), prefix="--totallength", doc=InputDocumentation(doc="Max total intron length (default 2400000)")), ToolInput(tag="in_chimera_margin", input_type=Int(optional=True), prefix="--chimera-margin", doc=InputDocumentation(doc="Amount of unaligned sequence that triggers\nsearch for the remaining sequence (default 30).\nEnables alignment of chimeric reads, and may help\nwith some non-chimeric reads.  To turn off, set to\nzero.")), ToolInput(tag="in_no_chimeras", input_type=Boolean(optional=True), prefix="--no-chimeras", doc=InputDocumentation(doc="Turns off finding of chimeras.  Same effect as --chimera-margin=0")), ToolInput(tag="in_n_threads", input_type=Int(optional=True), prefix="--nthreads", doc=InputDocumentation(doc="Number of worker threads")), ToolInput(tag="in_chr_subset", input_type=String(optional=True), prefix="--chrsubset", doc=InputDocumentation(doc="Limit search to given chromosome")), ToolInput(tag="in_strand", input_type=String(optional=True), prefix="--strand", doc=InputDocumentation(doc="Genome strand to try aligning to (plus, minus, or both default)")), ToolInput(tag="in_direction", input_type=String(optional=True), prefix="--direction", doc=InputDocumentation(doc="cDNA direction (sense_force, antisense_force,\nsense_filter, antisense_filter,or auto (default))")), ToolInput(tag="in_canonical_mode", input_type=Int(optional=True), prefix="--canonical-mode", doc=InputDocumentation(doc="Reward for canonical and semi-canonical introns\n0=low reward, 1=high reward (default), 2=low reward for\nhigh-identity sequences and high reward otherwise")), ToolInput(tag="in_cross_species", input_type=Boolean(optional=True), prefix="--cross-species", doc=InputDocumentation(doc="Use a more sensitive search for canonical splicing, which helps especially\nfor cross-species alignments and other difficult cases")), ToolInput(tag="in_allow_close_indels", input_type=Int(optional=True), prefix="--allow-close-indels", doc=InputDocumentation(doc="Allow an insertion and deletion close to each other\n(0=no, 1=yes (default), 2=only for high-quality alignments)")), ToolInput(tag="in_micro_exon_splice_prob", input_type=Float(optional=True), prefix="--microexon-spliceprob", doc=InputDocumentation(doc="Allow microexons only if one of the splice site probabilities is\ngreater than this value (default 0.95)")), ToolInput(tag="in_in_del_open", input_type=Boolean(optional=True), prefix="--indel-open", doc=InputDocumentation(doc="In dynamic programming, opening penalty for indel")), ToolInput(tag="in_in_del_extend", input_type=Boolean(optional=True), prefix="--indel-extend", doc=InputDocumentation(doc="In dynamic programming, extension penalty for indel\nValues for --indel-open and --indel-extend should be in [-127,-1].\nIf value is < -127, then will use -127 instead.\nIf --indel-open and --indel-extend are not specified, values are chosen\nadaptively, based on the differences between the query and reference")), ToolInput(tag="in_c_met_dir", input_type=Directory(optional=True), prefix="--cmetdir", doc=InputDocumentation(doc="Directory for methylcytosine index files (created using cmetindex)\n(default is location of genome index files specified using -D, -V, and -d)")), ToolInput(tag="in_atoi_dir", input_type=Directory(optional=True), prefix="--atoidir", doc=InputDocumentation(doc="Directory for A-to-I RNA editing index files (created using atoiindex)\n(default is location of genome index files specified using -D, -V, and -d)")), ToolInput(tag="in_alignment_mode_standard", input_type=String(optional=True), prefix="--mode", doc=InputDocumentation(doc="Alignment mode: standard (default), cmet-stranded, cmet-nonstranded,\natoi-stranded, atoi-nonstranded, ttoc-stranded, or ttoc-nonstranded.\nNon-standard modes requires you to have previously run the cmetindex\nor atoiindex programs (which also cover the ttoc modes) on the genome")), ToolInput(tag="in_prune_level", input_type=Boolean(optional=True), prefix="--prunelevel", doc=InputDocumentation(doc="Pruning level: 0=no pruning (default), 1=poor seqs,\n2=repetitive seqs, 3=poor and repetitive")), ToolInput(tag="in_summary", input_type=Boolean(optional=True), prefix="--summary", doc=InputDocumentation(doc="Show summary of alignments only")), ToolInput(tag="in_align", input_type=Boolean(optional=True), prefix="--align", doc=InputDocumentation(doc="Show alignments")), ToolInput(tag="in_continuous", input_type=Boolean(optional=True), prefix="--continuous", doc=InputDocumentation(doc="Show alignment in three continuous lines")), ToolInput(tag="in_continuous_by_exon", input_type=Boolean(optional=True), prefix="--continuous-by-exon", doc=InputDocumentation(doc="Show alignment in three lines per exon")), ToolInput(tag="in_exons", input_type=String(optional=True), prefix="--exons", doc=InputDocumentation(doc="Print exons ('cdna' or 'genomic')\nWill also print introns with 'cdna+introns' or\n'genomic+introns'")), ToolInput(tag="in_protein_dna", input_type=Boolean(optional=True), prefix="--protein_dna", doc=InputDocumentation(doc="Print protein sequence (cDNA)")), ToolInput(tag="in_protein_gen", input_type=Boolean(optional=True), prefix="--protein_gen", doc=InputDocumentation(doc="Print protein sequence (genomic)")), ToolInput(tag="in_format", input_type=File(optional=True), prefix="--format", doc=InputDocumentation(doc="Other format for output (also note the -A and -S options\nand other options listed under Output types):\nmask_introns,\nmask_utr_introns,\npsl (or 1) = PSL (BLAT) format,\ngff3_gene (or 2) = GFF3 gene format,\ngff3_match_cdna (or 3) = GFF3 cDNA_match format,\ngff3_match_est (or 4) = GFF3 EST_match format,\nsplicesites (or 6) = splicesites output (for GSNAP splicing file),\nintrons = introns output (for GSNAP splicing file),\nmap_exons (or 7) = IIT FASTA exon map format,\nmap_ranges (or 8) = IIT FASTA range map format,\ncoords (or 9) = coords in table format,\nsampe = SAM format (setting paired_read bit in flag),\nsamse = SAM format (without setting paired_read bit),\nbedpe = indels and gaps in BEDPE format")), ToolInput(tag="in_n_paths", input_type=Int(optional=True), prefix="--npaths", doc=InputDocumentation(doc="Maximum number of paths to show (default 5).  If set to 1, GMAP\nwill not report chimeric alignments, since those imply\ntwo paths.  If you want a single alignment plus chimeric\nalignments, then set this to be 0.")), ToolInput(tag="in_suboptimal_score", input_type=Float(optional=True), prefix="--suboptimal-score", doc=InputDocumentation(doc="Report only paths whose score is within this value of the\nbest path.\nIf specified between 0.0 and 1.0, then treated as a fraction\nof the score of the best alignment (matches minus penalties for\nmismatches and indels).  Otherwise, treated as an integer\nnumber to be subtracted from the score of the best alignment.\nDefault value is 0.50.")), ToolInput(tag="in_ordered", input_type=Boolean(optional=True), prefix="--ordered", doc=InputDocumentation(doc="Print output in same order as input (relevant\nonly if there is more than one worker thread)")), ToolInput(tag="in_md_five", input_type=Boolean(optional=True), prefix="--md5", doc=InputDocumentation(doc="Print MD5 checksum for each query sequence")), ToolInput(tag="in_chimera_overlap", input_type=Boolean(optional=True), prefix="--chimera-overlap", doc=InputDocumentation(doc="Overlap to show, if any, at chimera breakpoint")), ToolInput(tag="in_fails_only", input_type=Boolean(optional=True), prefix="--failsonly", doc=InputDocumentation(doc="Print only failed alignments, those with no results")), ToolInput(tag="in_no_fails", input_type=Boolean(optional=True), prefix="--nofails", doc=InputDocumentation(doc="Exclude printing of failed alignments")), ToolInput(tag="in_snps_dir", input_type=Directory(optional=True), prefix="--snpsdir", doc=InputDocumentation(doc="Directory for SNPs index files (created using snpindex) (default is\nlocation of genome index files specified using -D and -d)")), ToolInput(tag="in_use_snps", input_type=String(optional=True), prefix="--use-snps", doc=InputDocumentation(doc="Use database containing known SNPs (in <STRING>.iit, built\npreviously using snpindex) for tolerance to SNPs")), ToolInput(tag="in_split_output", input_type=File(optional=True), prefix="--split-output", doc=InputDocumentation(doc="Basename for multiple-file output, separately for nomapping,\nuniq, mult, (and chimera, if --chimera-margin is selected)")), ToolInput(tag="in_failed_input", input_type=File(optional=True), prefix="--failed-input", doc=InputDocumentation(doc="Print completely failed alignments as input FASTA or FASTQ format\nto the given file.  If the --split-output flag is also given, this file\nis generated in addition to the output in the .nomapping file.")), ToolInput(tag="in_append_output", input_type=Boolean(optional=True), prefix="--append-output", doc=InputDocumentation(doc="When --split-output or --failedinput is given, this flag will append output\nto the existing files.  Otherwise, the default is to create new files.")), ToolInput(tag="in_output_buffer_size", input_type=Int(optional=True), prefix="--output-buffer-size", doc=InputDocumentation(doc="Buffer size, in queries, for output thread (default 1000).  When the number\nof results to be printed exceeds this size, worker threads wait\nuntil the backlog is cleared")), ToolInput(tag="in_translation_code", input_type=Int(optional=True), prefix="--translation-code", doc=InputDocumentation(doc="Genetic code used for translating codons to amino acids and computing CDS\nInteger value (default=1) corresponds to an available code at\nhttp://www.ncbi.nlm.nih.gov/Taxonomy/Utils/wprintgc.cgi")), ToolInput(tag="in_alt_start_codons", input_type=Boolean(optional=True), prefix="--alt-start-codons", doc=InputDocumentation(doc="Also, use the alternate initiation codons shown in the above Web site\nBy default, without this option, only ATG is considered an initiation codon")), ToolInput(tag="in_full_length", input_type=Boolean(optional=True), prefix="--fulllength", doc=InputDocumentation(doc="Assume full-length protein, starting with Met")), ToolInput(tag="in_cds_start", input_type=Int(optional=True), prefix="--cdsstart", doc=InputDocumentation(doc="Translate codons from given nucleotide (1-based)")), ToolInput(tag="in_truncate", input_type=Boolean(optional=True), prefix="--truncate", doc=InputDocumentation(doc="Truncate alignment around full-length protein, Met to Stop\nImplies -F flag.")), ToolInput(tag="in_tolerant", input_type=Boolean(optional=True), prefix="--tolerant", doc=InputDocumentation(doc="Translates cDNA with corrections for frameshifts")), ToolInput(tag="in_gff_three_add_separators", input_type=Int(optional=True), prefix="--gff3-add-separators", doc=InputDocumentation(doc="Whether to add a ### separator after each query sequence\nValues: 0 (no), 1 (yes, default)")), ToolInput(tag="in_gff_three_swap_phase", input_type=Int(optional=True), prefix="--gff3-swap-phase", doc=InputDocumentation(doc="Whether to swap phase (0 => 0, 1 => 2, 2 => 1) in gff3_gene format\nNeeded by some analysis programs, but deviates from GFF3 specification\nValues: 0 (no, default), 1 (yes)")), ToolInput(tag="in_gff_three_fast_a_annotation", input_type=Int(optional=True), prefix="--gff3-fasta-annotation", doc=InputDocumentation(doc="Whether to include annotation from the FASTA header into the GFF3 output\nValues: 0 (default): Do not include\n1: Wrap all annotation as Annot='<header>'\n2: Include key=value pairs, replacing brackets with quotation marks\nand replacing spaces between key=value pairs with semicolons")), ToolInput(tag="in_gff_three_cds", input_type=Int(optional=True), prefix="--gff3-cds", doc=InputDocumentation(doc="Whether to use cDNA or genomic translation for the CDS coordinates\nValues: cdna (default), genomic")), ToolInput(tag="in_no_sam_headers", input_type=Boolean(optional=True), prefix="--no-sam-headers", doc=InputDocumentation(doc="Do not print headers beginning with '@'")), ToolInput(tag="in_sam_use_zero_m", input_type=Boolean(optional=True), prefix="--sam-use-0M", doc=InputDocumentation(doc="Insert 0M in CIGAR between adjacent insertions and deletions\nRequired by Picard, but can cause errors in other tools")), ToolInput(tag="in_sam_extended_cigar", input_type=Boolean(optional=True), prefix="--sam-extended-cigar", doc=InputDocumentation(doc="Use extended CIGAR format (using X and = symbols instead of M,\nto indicate matches and mismatches, respectively")), ToolInput(tag="in_force_xs_dir", input_type=Boolean(optional=True), prefix="--force-xs-dir", doc=InputDocumentation(doc="For RNA-Seq alignments, disallows XS:A:? when the sense direction\nis unclear, and replaces this value arbitrarily with XS:A:+.\nMay be useful for some programs, such as Cufflinks, that cannot\nhandle XS:A:?.  However, if you use this flag, the reported value\nof XS:A:+ in these cases will not be meaningful.")), ToolInput(tag="in_md_lowercase_snp", input_type=Boolean(optional=True), prefix="--md-lowercase-snp", doc=InputDocumentation(doc="In MD string, when known SNPs are given by the -v flag,\nprints difference nucleotides as lower-case when they,\ndiffer from reference but match a known alternate allele")), ToolInput(tag="in_action_if_cigar_error", input_type=Boolean(optional=True), prefix="--action-if-cigar-error", doc=InputDocumentation(doc="Action to take if there is a disagreement between CIGAR length and sequence length\nAllowed values: ignore, warning (default), noprint, abort\nNote that the noprint option does not print the CIGAR string at all if there\nis an error, so it may break a SAM parser")), ToolInput(tag="in_read_group_id", input_type=String(optional=True), prefix="--read-group-id", doc=InputDocumentation(doc="Value to put into read-group id (RG-ID) field")), ToolInput(tag="in_read_group_name", input_type=String(optional=True), prefix="--read-group-name", doc=InputDocumentation(doc="Value to put into read-group name (RG-SM) field")), ToolInput(tag="in_read_group_library", input_type=String(optional=True), prefix="--read-group-library", doc=InputDocumentation(doc="Value to put into read-group library (RG-LB) field")), ToolInput(tag="in_read_group_platform", input_type=String(optional=True), prefix="--read-group-platform", doc=InputDocumentation(doc="Value to put into read-group library (RG-PL) field")), ToolInput(tag="in_quality_protocol", input_type=Int(optional=True), prefix="--quality-protocol", doc=InputDocumentation(doc="Protocol for input quality scores.  Allowed values:\nillumina (ASCII 64-126) (equivalent to -J 64 -j -31)\nsanger   (ASCII 33-126) (equivalent to -J 33 -j 0)\nDefault is sanger (no quality print shift)\nSAM output files should have quality scores in sanger protocol\nOr you can specify the print shift with this flag:")), ToolInput(tag="in_quality_print_shift", input_type=Int(optional=True), prefix="--quality-print-shift", doc=InputDocumentation(doc="Shift FASTQ quality scores by this amount in output\n(default is 0 for sanger protocol; to change Illumina input\nto Sanger output, select -31)")), ToolInput(tag="in_map_dir", input_type=Directory(optional=True), prefix="--mapdir", doc=InputDocumentation(doc="Map directory")), ToolInput(tag="in_map", input_type=File(optional=True), prefix="--map", doc=InputDocumentation(doc="Map file.  If argument is '?' (with the quotes),\nthis lists available map files.")), ToolInput(tag="in_map_exons", input_type=Boolean(optional=True), prefix="--mapexons", doc=InputDocumentation(doc="Map each exon separately")), ToolInput(tag="in_map_both", input_type=Boolean(optional=True), prefix="--mapboth", doc=InputDocumentation(doc="Report hits from both strands of genome")), ToolInput(tag="in_flanking", input_type=Int(optional=True), prefix="--flanking", doc=InputDocumentation(doc="Show flanking hits (default 0)")), ToolInput(tag="in_print_comment", input_type=Boolean(optional=True), prefix="--print-comment", doc=InputDocumentation(doc="Show comment line for each hit")), ToolInput(tag="in_no_lengths", input_type=Boolean(optional=True), prefix="--nolengths", doc=InputDocumentation(doc="No intron lengths in alignment")), ToolInput(tag="in_no_margin", input_type=Boolean(optional=True), prefix="--nomargin", doc=InputDocumentation(doc="No left margin in GMAP standard output (with the -A flag)")), ToolInput(tag="in_invert_mode", input_type=Int(optional=True), prefix="--invertmode", doc=InputDocumentation(doc="Mode for alignments to genomic (-) strand:\n0=Don't invert the cDNA (default)\n1=Invert cDNA and print genomic (-) strand\n2=Invert cDNA and print genomic (+) strand")), ToolInput(tag="in_intron_gap", input_type=Int(optional=True), prefix="--introngap", doc=InputDocumentation(doc="Nucleotides to show on each end of intron (default 3)")), ToolInput(tag="in_wrap_length", input_type=Int(optional=True), prefix="--wraplength", doc=InputDocumentation(doc="Wrap length for alignment (default 50)")), ToolInput(tag="in_min_trimmed_coverage", input_type=Float(optional=True), prefix="--min-trimmed-coverage", doc=InputDocumentation(doc="Do not print alignments with trimmed coverage less\nthis value (default=0.0, which means no filtering)\nNote that chimeric alignments will be output regardless\nof this filter")), ToolInput(tag="in_min_identity", input_type=Float(optional=True), prefix="--min-identity", doc=InputDocumentation(doc="Do not print alignments with identity less\nthis value (default=0.0, which means no filtering)\nNote that chimeric alignments will be output regardless\nof this filter")), ToolInput(tag="in_check", input_type=Boolean(optional=True), prefix="--check", doc=InputDocumentation(doc="Check compiler assumptions")), ToolInput(tag="in_positions_mmap_mmap", input_type=String(), position=0, doc=InputDocumentation(doc="Positions       Genome\n0      mmap            mmap\n1      mmap & preload  mmap"))], outputs=[ToolOutput(tag="out_format", output_type=File(optional=True), selector=InputSelector(input_to_select="in_format", type_hint=File()), doc=OutputDocumentation(doc="Other format for output (also note the -A and -S options\nand other options listed under Output types):\nmask_introns,\nmask_utr_introns,\npsl (or 1) = PSL (BLAT) format,\ngff3_gene (or 2) = GFF3 gene format,\ngff3_match_cdna (or 3) = GFF3 cDNA_match format,\ngff3_match_est (or 4) = GFF3 EST_match format,\nsplicesites (or 6) = splicesites output (for GSNAP splicing file),\nintrons = introns output (for GSNAP splicing file),\nmap_exons (or 7) = IIT FASTA exon map format,\nmap_ranges (or 8) = IIT FASTA range map format,\ncoords (or 9) = coords in table format,\nsampe = SAM format (setting paired_read bit in flag),\nsamse = SAM format (without setting paired_read bit),\nbedpe = indels and gaps in BEDPE format")), ToolOutput(tag="out_split_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_split_output", type_hint=File()), doc=OutputDocumentation(doc="Basename for multiple-file output, separately for nomapping,\nuniq, mult, (and chimera, if --chimera-margin is selected)"))], container="quay.io/biocontainers/gmap:2021.03.08--pl5262h36cd882_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Gmapl_Sse42_V0_1_0().translate("wdl")

